==> blanco.plugin.dbphp_0.0.9-src.zip: blancoDbPhpPlugin/blanco/main/blanco/plugin/dbphp/resourcebundle/BlancoDbPhpPluginResourceBundle.java <==
/*
 * ̃\[XR[h blanco FrameworkɂĎĂ܂B
 * \[Xoh`쐬ꂽ\[XohNXB
 */
package blanco.plugin.dbphp.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * \[Xoh`[BlancoDbPhpPlugin]̃\[XohNXB
 *
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoDbPhpPluginResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoDbPhpPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbPhpPlugin]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoDbPhpPluginResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbPhpPlugin");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoDbPhpPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbPhpPlugin]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoDbPhpPluginResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbPhpPlugin", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoDbPhpPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbPhpPlugin]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoDbPhpPluginResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("BlancoDbPhpPlugin", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoDbPhpPlugin], key[CLEAR_TMP_FOLDER]
     *
     * [true] (ja)<br>
     *
     * @return key[CLEAR_TMP_FOLDER]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClearTmpFolder() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "true";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLEAR_TMP_FOLDER");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}

==> blanco.plugin.dbphp_0.1.2-src.zip: blancoDbPhpPlugin/blanco/main/blanco/plugin/dbphp/resourcebundle/BlancoDbPhpPluginResourceBundle.java <==
/*
 * ̃\[XR[h blanco Frameworkɂ莩܂B
 */
package blanco.plugin.dbphp.resourcebundle;

import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;

/**
 * BlancoDbPhpvOC̃\[XohłB
 *
 * \[Xoh`: [BlancoDbPhpPlugin]B<BR>
 * ̃NX̓\[Xoh`玩ꂽ\[XohNXłB<BR>
 * m̃P[<BR>
 * <UL>
 * <LI>ja
 * </UL>
 */
public class BlancoDbPhpPluginResourceBundle {
    /**
     * \[XohIuWFNgB
     *
     * IɎۂɓ͂s\[XohL܂B
     */
    private ResourceBundle fResourceBundle;

    /**
     * BlancoDbPhpPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbPhpPlugin]AftHg̃P[AĂяõNX[_gpāA\[Xoh擾܂B
     */
    public BlancoDbPhpPluginResourceBundle() {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/plugin/dbphp/resourcebundle/BlancoDbPhpPlugin");
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoDbPhpPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbPhpPlugin]Aw肳ꂽP[AĂяõNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     */
    public BlancoDbPhpPluginResourceBundle(final Locale locale) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/plugin/dbphp/resourcebundle/BlancoDbPhpPlugin", locale);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * BlancoDbPhpPluginResourceBundleNX̃RXgN^B
     *
     * ꖼ[BlancoDbPhpPlugin]Aw肳ꂽP[Aw肳ꂽNX[_gpāA\[Xoh擾܂B
     *
     * @param locale P[̎w
     * @param loader NX[_̎w
     */
    public BlancoDbPhpPluginResourceBundle(final Locale locale, final ClassLoader loader) {
        try {
            fResourceBundle = ResourceBundle.getBundle("blanco/plugin/dbphp/resourcebundle/BlancoDbPhpPlugin", locale, loader);
        } catch (MissingResourceException ex) {
        }
    }

    /**
     * IɕێĂ郊\[XohIuWFNg擾܂B
     *
     * @return IɕێĂ郊\[XohIuWFNgB
     */
    public ResourceBundle getResourceBundle() {
        return fResourceBundle;
    }

    /**
     * bundle[BlancoDbPhpPlugin], key[CLEAR_TMP_FOLDER]
     *
     * [true] (ja)<br>
     *
     * @return key[CLEAR_TMP_FOLDER]ɑΉlBOǂݍ݂łȂꍇɂ́A`̒l߂܂BKnullȊO̒l߂܂B
     */
    public String getClearTmpFolder() {
        // lƂĒ`̒l𗘗p܂B
        String strFormat = "true";
        try {
            if (fResourceBundle != null) {
                strFormat = fResourceBundle.getString("CLEAR_TMP_FOLDER");
            }
        } catch (MissingResourceException ex) {
        }
        // u͂ЂƂ܂B
        return strFormat;
    }
}
